/**
 * Copyright (c) 2019-2023 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Adam Midlik <midlik@gmail.com>
 *
 * Manage dependencies which are not listed in `package.json` for performance reasons.
 */
/** Define imports that only get imported when first needed.
 * Example usage:
 * ```
 * const lazyImports = LazyImports.create('gl', 'jpeg-js', 'pngjs') as {
 *     'gl': typeof import('gl'),
 *     'jpeg-js': typeof import('jpeg-js'),
 *     'pngjs': typeof import('pngjs'),
 * };
 * ...
 * lazyImports.pngjs.blablabla("I'm being imported now");
 * lazyImports.pngjs.blablabla("I'm cached :D");
 * ```
 */
export declare class LazyImports {
    private packages;
    static create<U extends string>(...packages: U[]): {
        [dep in U]: any;
    };
    private constructor();
    private getPackage;
}
